==> v0.8.5.tar.gz: icebergs/core/code/sh.go <==
package code

import (
	ice "shylinux.com/x/icebergs"
	"shylinux.com/x/icebergs/base/cli"
	"shylinux.com/x/icebergs/base/mdb"
	kit "shylinux.com/x/toolkits"
)

const SH = "sh"

func init() {
	Index.Register(&ice.Context{Name: SH, Help: "命令", Commands: map[string]*ice.Command{
		ice.CTX_INIT: {Hand: func(m *ice.Message, c *ice.Context, cmd string, arg ...string) {
			for _, cmd := range []string{mdb.SEARCH, mdb.ENGINE, mdb.RENDER, mdb.PLUGIN} {
				m.Cmd(cmd, mdb.CREATE, SH, m.Prefix(SH))
			}
			LoadPlug(m, SH)
		}},
		SH: {Name: SH, Help: "命令", Action: ice.MergeAction(map[string]*ice.Action{
			mdb.SEARCH: {Hand: func(m *ice.Message, arg ...string) {
				if arg[0] == mdb.FOREACH {
					return
				}
				m.Option(cli.CMD_DIR, kit.Select(ice.SRC, arg, 2))
				m.Cmdy(mdb.SEARCH, MAN1, arg[1:])
				m.Cmdy(mdb.SEARCH, MAN8, arg[1:])
				_go_find(m, kit.Select(MAIN, arg, 1), arg[2])
				_go_grep(m, kit.Select(MAIN, arg, 1), arg[2])
			}},
			mdb.ENGINE: {Hand: func(m *ice.Message, arg ...string) {
				m.Cmdy(cli.SYSTEM, SH, arg[1], kit.Dict(cli.CMD_DIR, arg[2])).SetAppend()
			}},
			MAN: {Hand: func(m *ice.Message, arg ...string) {
				m.Echo(_c_help(m, arg[0], arg[1]))
			}},
		}, PlugAction())},
	}, Configs: map[string]*ice.Config{
		SH: {Name: SH, Help: "命令", Value: kit.Data(PLUG, kit.Dict(
			SPLIT, kit.Dict("space", " ", "operator", "{[(.,;!|<>)]}"),
			PREFIX, kit.Dict("#", COMMENT),
			SUFFIX, kit.Dict("{", COMMENT),
			PREPARE, kit.Dict(
				KEYWORD, kit.Simple(
					"export",
					"source",
					"require",

					"if",
					"then",
					"else",
					"fi",
					"for",
					"while",
					"do",
					"done",
					"esac",
					"case",
					"in",
					"return",

					"shift",
					"local",
					"echo",
					"eval",
					"kill",
					"let",
					"cd",
				),
				FUNCTION, kit.Simple(
					"xargs",
					"date",
					"find",
					"grep",
					"sed",
					"awk",
					"pwd",
					"ps",
					"ls",
					"rm",
					"go",
				),
			), KEYWORD, kit.Dict(),
		))},
	}}, nil)
}

==> v0.9.9.tar.gz: icebergs/core/code/sh.go <==
package code

import (
	ice "shylinux.com/x/icebergs"
	"shylinux.com/x/icebergs/base/cli"
	"shylinux.com/x/icebergs/base/mdb"
	kit "shylinux.com/x/toolkits"
)

const SH = "sh"

func init() {
	Index.Register(&ice.Context{Name: SH, Help: "命令", Commands: map[string]*ice.Command{
		SH: {Name: SH, Help: "命令", Action: ice.MergeAction(map[string]*ice.Action{
			ice.CTX_INIT: {Hand: func(m *ice.Message, arg ...string) {
				for _, cmd := range []string{mdb.SEARCH, mdb.ENGINE, mdb.RENDER, mdb.PLUGIN} {
					m.Cmd(cmd, mdb.CREATE, SH, m.PrefixKey())
				}
				LoadPlug(m, SH)
			}},
			mdb.ENGINE: {Hand: func(m *ice.Message, arg ...string) {
				m.Cmdy(cli.SYSTEM, SH, "-c", `#! /bin/sh

source `+arg[1]+`
`, kit.Dict(cli.CMD_DIR, arg[2])).SetAppend()
			}},
			mdb.SEARCH: {Hand: func(m *ice.Message, arg ...string) {
				if arg[0] == mdb.FOREACH {
					return
				}
				m.Option(cli.CMD_DIR, kit.Select(ice.SRC, arg, 2))
				m.Cmdy(mdb.SEARCH, MAN1, arg[1:])
				m.Cmdy(mdb.SEARCH, MAN8, arg[1:])
				_go_find(m, kit.Select(cli.MAIN, arg, 1), arg[2])
				_go_grep(m, kit.Select(cli.MAIN, arg, 1), arg[2])
			}},
			MAN: {Hand: func(m *ice.Message, arg ...string) {
				m.Echo(_c_help(m, arg[0], arg[1]))
			}},
		}, PlugAction())},
	}, Configs: map[string]*ice.Config{
		SH: {Name: SH, Help: "命令", Value: kit.Data(PLUG, kit.Dict(
			mdb.ENGINE, kit.Dict(),
			SPLIT, kit.Dict("space", " ", "operator", "{[(.,;!|<>)]}"),
			PREFIX, kit.Dict("#", COMMENT),
			SUFFIX, kit.Dict("{", COMMENT),
			PREPARE, kit.Dict(
				KEYWORD, kit.Simple(
					"export",
					"source",
					"require",

					"if",
					"then",
					"else",
					"fi",
					"for",
					"while",
					"do",
					"done",
					"esac",
					"case",
					"in",
					"return",

					"shift",
					"local",
					"echo",
					"eval",
					"kill",
					"let",
					"cd",
				),
				FUNCTION, kit.Simple(
					"xargs",
					"date",
					"find",
					"grep",
					"sed",
					"awk",
					"pwd",
					"ps",
					"ls",
					"rm",
					"go",
				),
			), KEYWORD, kit.Dict(),
		))},
	}}, nil)
}
